@@ -78,9 +78,9 @@ DBusGMainLoop(set_as_default=True)
 sys_bus = dbus.SystemBus()
 
 #get initial states
-mce_proxy_request = sys_bus.get_object('com.nokia.mce', '/com/nokia/mce/request')
-mce_request_iface = dbus.Interface(mce_proxy_request, dbus_interface='com.nokia.mce.request')
-ts_kb_locked(mce_request_iface.get_tklock_mode())
+#mce_proxy_request = sys_bus.get_object('com.nokia.mce', '/com/nokia/mce/request')
+#mce_request_iface = dbus.Interface(mce_proxy_request, dbus_interface='com.nokia.mce.request')
+#ts_kb_locked(mce_request_iface.get_tklock_mode())
 
 #watch for changes
 sys_bus.add_signal_receiver(ts_kb_locked, path='/com/nokia/mce/signal', dbus_interface='com.nokia.mce.signal', signal_name='tklock_mode_ind')
